ChannelRequest

Enum ChannelRequest 

pub enum ChannelRequest {
    CreateChannel {
        handles: [NewHandleId; 2],
        responder: ChannelCreateChannelResponder,
    },
    ReadChannel {
        handle: HandleId,
        responder: ChannelReadChannelResponder,
    },
    WriteChannel {
        handle: HandleId,
        data: Vec<u8>,
        handles: Handles,
        responder: ChannelWriteChannelResponder,
    },
    ReadChannelStreamingStart {
        handle: HandleId,
        responder: ChannelReadChannelStreamingStartResponder,
    },
    ReadChannelStreamingStop {
        handle: HandleId,
        responder: ChannelReadChannelStreamingStopResponder,
    },
#[non_exhaustive]
_UnknownMethod { ordinal: u64, control_handle: ChannelControlHandle, method_type: MethodType, }, }
FDomain operations on Channels.

Variants



CreateChannel

Create a new channel in this FDomain and return both its ends.

Fields

handles: [NewHandleId; 2]


ReadChannel

Read a message from a channel. This method will fail if the channel is currently being read using the streaming read functions.

Note that this method is not like zx_channel_read in that it will not return SHOULD_WAIT but will instead delay returning until there is data to return.



WriteChannel

Write to a channel. Handles are always consumed.

Fields

handle: HandleId
data: Vec<u8>
handles: Handles


ReadChannelStreamingStart

Starts reading from the given channel. Data is returned via the ChannelStreamingData event. That event will occur repeatedly until ReadChannelStreamingStop is called for the same handle or the event indicates the handle is closed.



ReadChannelStreamingStop

Stop asynchronous reading from the given channel.



#[non_exhaustive]
_UnknownMethod

An interaction was received which does not match any known method.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
ordinal: u64

Ordinal of the method that was called.

control_handle: ChannelControlHandle
method_type: MethodType

Implementations