SocketRequest

Enum SocketRequest 

pub enum SocketRequest {
    CreateSocket {
        options: SocketType,
        handles: [NewHandleId; 2],
        responder: SocketCreateSocketResponder,
    },
    SetSocketDisposition {
        handle: HandleId,
        disposition: SocketDisposition,
        disposition_peer: SocketDisposition,
        responder: SocketSetSocketDispositionResponder,
    },
    ReadSocket {
        handle: HandleId,
        max_bytes: u64,
        responder: SocketReadSocketResponder,
    },
    WriteSocket {
        handle: HandleId,
        data: Vec<u8>,
        responder: SocketWriteSocketResponder,
    },
    ReadSocketStreamingStart {
        handle: HandleId,
        responder: SocketReadSocketStreamingStartResponder,
    },
    ReadSocketStreamingStop {
        handle: HandleId,
        responder: SocketReadSocketStreamingStopResponder,
    },
#[non_exhaustive]
_UnknownMethod { ordinal: u64, control_handle: SocketControlHandle, method_type: MethodType, }, }
FDomain operations on sockets

Variants



CreateSocket

Create a new socket in this FDomain and return both its ends.

Fields

options: SocketType
handles: [NewHandleId; 2]


SetSocketDisposition

Set the disposition of a given socket.



ReadSocket

Read data from a socket. This method will fail if the socket is currently being read asynchronously.

Fields

handle: HandleId
max_bytes: u64


WriteSocket

Write to a socket. This will attempt to write all the data passed, and will block and retry whenever it is safe (e.g. it should never return SHOULD_WAIT). The WriteSocketError contains a wrote parameter to indicate if some bytes were written successfully before the failure occurred.

Fields

handle: HandleId
data: Vec<u8>


ReadSocketStreamingStart

Starts reading from the given socket. Data is returned via the SocketStreamingData event. That event will occur repeatedly until ReadSocketStreamingStop is called for the same handle or the event indicates the handle is closed.



ReadSocketStreamingStop

Stop asynchronous reading from the given socket.



#[non_exhaustive]
_UnknownMethod

An interaction was received which does not match any known method.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
ordinal: u64

Ordinal of the method that was called.

control_handle: SocketControlHandle
method_type: MethodType

Implementations