FDomainProxy

Struct FDomainProxy 

pub struct FDomainProxy { /* private fields */ }

Implementations

Source

impl FDomainProxy

pub fn new(channel: AsyncChannel) -> Self

Create a new Proxy for fuchsia.fdomain/FDomain.

pub fn take_event_stream(&self) -> FDomainEventStream

Get a Stream of events from the remote end of the protocol.

Panics

Panics if the event stream was already taken.

pub fn create_channel( &self, handles: &[NewHandleId; 2], ) -> QueryResponseFut<ChannelCreateChannelResult, DefaultFuchsiaResourceDialect>

Create a new channel in this FDomain and return both its ends.

pub fn read_channel( &self, handle: &HandleId, ) -> QueryResponseFut<ChannelReadChannelResult, DefaultFuchsiaResourceDialect>

Read a message from a channel. This method will fail if the channel is currently being read using the streaming read functions.

Note that this method is not like zx_channel_read in that it will not return SHOULD_WAIT but will instead delay returning until there is data to return.

pub fn write_channel( &self, handle: &HandleId, data: &[u8], handles: &Handles, ) -> QueryResponseFut<ChannelWriteChannelResult, DefaultFuchsiaResourceDialect>

Write to a channel. Handles are always consumed.

pub fn read_channel_streaming_start( &self, handle: &HandleId, ) -> QueryResponseFut<ChannelReadChannelStreamingStartResult, DefaultFuchsiaResourceDialect>

Starts reading from the given channel. Data is returned via the ChannelStreamingData event. That event will occur repeatedly until ReadChannelStreamingStop is called for the same handle or the event indicates the handle is closed.

pub fn read_channel_streaming_stop( &self, handle: &HandleId, ) -> QueryResponseFut<ChannelReadChannelStreamingStopResult, DefaultFuchsiaResourceDialect>

Stop asynchronous reading from the given channel.

pub fn create_event( &self, handle: &NewHandleId, ) -> QueryResponseFut<EventCreateEventResult, DefaultFuchsiaResourceDialect>

Create a new event in this FDomain and return it.

pub fn create_event_pair( &self, handles: &[NewHandleId; 2], ) -> QueryResponseFut<EventPairCreateEventPairResult, DefaultFuchsiaResourceDialect>

Create a new event pair in this FDomain and return both its ends.

pub fn create_socket( &self, options: SocketType, handles: &[NewHandleId; 2], ) -> QueryResponseFut<SocketCreateSocketResult, DefaultFuchsiaResourceDialect>

Create a new socket in this FDomain and return both its ends.

pub fn set_socket_disposition( &self, handle: &HandleId, disposition: SocketDisposition, disposition_peer: SocketDisposition, ) -> QueryResponseFut<SocketSetSocketDispositionResult, DefaultFuchsiaResourceDialect>

Set the disposition of a given socket.

pub fn read_socket( &self, handle: &HandleId, max_bytes: u64, ) -> QueryResponseFut<SocketReadSocketResult, DefaultFuchsiaResourceDialect>

Read data from a socket. This method will fail if the socket is currently being read asynchronously.

pub fn write_socket( &self, handle: &HandleId, data: &[u8], ) -> QueryResponseFut<SocketWriteSocketResult, DefaultFuchsiaResourceDialect>

Write to a socket. This will attempt to write all the data passed, and will block and retry whenever it is safe (e.g. it should never return SHOULD_WAIT). The WriteSocketError contains a wrote parameter to indicate if some bytes were written successfully before the failure occurred.

pub fn read_socket_streaming_start( &self, handle: &HandleId, ) -> QueryResponseFut<SocketReadSocketStreamingStartResult, DefaultFuchsiaResourceDialect>

Starts reading from the given socket. Data is returned via the SocketStreamingData event. That event will occur repeatedly until ReadSocketStreamingStop is called for the same handle or the event indicates the handle is closed.

pub fn read_socket_streaming_stop( &self, handle: &HandleId, ) -> QueryResponseFut<SocketReadSocketStreamingStopResult, DefaultFuchsiaResourceDialect>

Stop asynchronous reading from the given socket.

pub fn get_namespace( &self, new_handle: &NewHandleId, ) -> QueryResponseFut<FDomainGetNamespaceResult, DefaultFuchsiaResourceDialect>

Adds a new channel handle to this namespace which points to a fuchsia.io.Directory. Can be used to “bootstrap” the FDomain.

pub fn close( &self, handles: &[HandleId], ) -> QueryResponseFut<FDomainCloseResult, DefaultFuchsiaResourceDialect>

Close one or more handles.

pub fn duplicate( &self, handle: &HandleId, new_handle: &NewHandleId, rights: Rights, ) -> QueryResponseFut<FDomainDuplicateResult, DefaultFuchsiaResourceDialect>

Duplicate a handle.

pub fn replace( &self, handle: &HandleId, new_handle: &NewHandleId, rights: Rights, ) -> QueryResponseFut<FDomainReplaceResult, DefaultFuchsiaResourceDialect>

Close a handle and replace it with a new one with possibly different rights.

pub fn signal( &self, handle: &HandleId, set: u32, clear: u32, ) -> QueryResponseFut<FDomainSignalResult, DefaultFuchsiaResourceDialect>

Set or clear signals on a handle.

pub fn signal_peer( &self, handle: &HandleId, set: u32, clear: u32, ) -> QueryResponseFut<FDomainSignalPeerResult, DefaultFuchsiaResourceDialect>

Set or clear signals on a handle’s peer.

pub fn wait_for_signals( &self, handle: &HandleId, signals: u32, ) -> QueryResponseFut<FDomainWaitForSignalsResult, DefaultFuchsiaResourceDialect>

Wait for signals from the given handle. Reply will be returned when one of the given signals is asserted.

pub fn get_koid( &self, handle: &HandleId, ) -> QueryResponseFut<FDomainGetKoidResult, DefaultFuchsiaResourceDialect>

Return the kernel object ID (koid) of the handle.