#[repr(C)]pub struct VmoGetVmoSizeRequest {
pub handle: HandleId,
}Fields
handle: HandleIdTrait Implementations
Sourceimpl Clone for VmoGetVmoSizeRequest
impl Clone for VmoGetVmoSizeRequest
Sourcefn clone(&self) -> VmoGetVmoSizeRequest
fn clone(&self) -> VmoGetVmoSizeRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for VmoGetVmoSizeRequest
Sourceimpl Debug for VmoGetVmoSizeRequest
impl Debug for VmoGetVmoSizeRequest
Sourceimpl<D> Decode<VmoGetVmoSizeRequest, D> for VmoGetVmoSizeRequestwhere
D: ResourceDialect,
impl<D> Decode<VmoGetVmoSizeRequest, D> for VmoGetVmoSizeRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> VmoGetVmoSizeRequest
fn new_empty() -> VmoGetVmoSizeRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<VmoGetVmoSizeRequest, D> for &VmoGetVmoSizeRequestwhere
D: ResourceDialect,
impl<D> Encode<VmoGetVmoSizeRequest, D> for &VmoGetVmoSizeRequestwhere
D: ResourceDialect,
impl Eq for VmoGetVmoSizeRequest
Sourceimpl Hash for VmoGetVmoSizeRequest
impl Hash for VmoGetVmoSizeRequest
Sourceimpl Ord for VmoGetVmoSizeRequest
impl Ord for VmoGetVmoSizeRequest
Sourcefn cmp(&self, other: &VmoGetVmoSizeRequest) -> Ordering
fn cmp(&self, other: &VmoGetVmoSizeRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for VmoGetVmoSizeRequest
impl PartialEq for VmoGetVmoSizeRequest
Sourceimpl PartialOrd for VmoGetVmoSizeRequest
impl PartialOrd for VmoGetVmoSizeRequest
impl Persistable for VmoGetVmoSizeRequest
impl StructuralPartialEq for VmoGetVmoSizeRequest
Sourceimpl TypeMarker for VmoGetVmoSizeRequest
impl TypeMarker for VmoGetVmoSizeRequest
Sourcetype Owned = VmoGetVmoSizeRequest
type Owned = VmoGetVmoSizeRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for VmoGetVmoSizeRequest
impl ValueTypeMarker for VmoGetVmoSizeRequest
Sourcetype Borrowed<'a> = &'a VmoGetVmoSizeRequest
type Borrowed<'a> = &'a VmoGetVmoSizeRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<VmoGetVmoSizeRequest as TypeMarker>::Owned,
) -> <VmoGetVmoSizeRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<VmoGetVmoSizeRequest as TypeMarker>::Owned, ) -> <VmoGetVmoSizeRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for VmoGetVmoSizeRequest
impl RefUnwindSafe for VmoGetVmoSizeRequest
impl Send for VmoGetVmoSizeRequest
impl Sync for VmoGetVmoSizeRequest
impl Unpin for VmoGetVmoSizeRequest
impl UnsafeUnpin for VmoGetVmoSizeRequest
impl UnwindSafe for VmoGetVmoSizeRequest