pub struct VmoMarker;Trait Implementations
impl Copy for VmoMarker
impl Eq for VmoMarker
Sourceimpl Ord for VmoMarker
impl Ord for VmoMarker
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for VmoMarker
impl PartialOrd for VmoMarker
Sourceimpl ProtocolMarker for VmoMarker
impl ProtocolMarker for VmoMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) Vmo"
const DEBUG_NAME: &'static str = "(anonymous) Vmo"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = VmoProxy
type Proxy = VmoProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = VmoRequestStream
type RequestStream = VmoRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = VmoSynchronousProxy
type SynchronousProxy = VmoSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for VmoMarker