pub struct VmoOptions(/* private fields */);Expand description
Options for creating a VMO.
Implementations
Sourceimpl VmoOptions
impl VmoOptions
pub const RESIZABLE: VmoOptions
pub const TRAP_DIRTY: VmoOptions
pub const UNBOUNDED: VmoOptions
Sourceimpl VmoOptions
impl VmoOptions
Sourcepub const fn empty() -> VmoOptions
pub const fn empty() -> VmoOptions
Get a flags value with all bits unset.
Sourcepub const fn all() -> VmoOptions
pub const fn all() -> VmoOptions
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<VmoOptions>
pub const fn from_bits(bits: u32) -> Option<VmoOptions>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> VmoOptions
pub const fn from_bits_truncate(bits: u32) -> VmoOptions
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> VmoOptions
pub const fn from_bits_retain(bits: u32) -> VmoOptions
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<VmoOptions>
pub fn from_name(name: &str) -> Option<VmoOptions>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: VmoOptions) -> bool
pub const fn intersects(&self, other: VmoOptions) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: VmoOptions) -> bool
pub const fn contains(&self, other: VmoOptions) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: VmoOptions)
pub fn insert(&mut self, other: VmoOptions)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: VmoOptions)
pub fn remove(&mut self, other: VmoOptions)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: VmoOptions)
pub fn toggle(&mut self, other: VmoOptions)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: VmoOptions, value: bool)
pub fn set(&mut self, other: VmoOptions, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: VmoOptions) -> VmoOptions
pub const fn intersection(self, other: VmoOptions) -> VmoOptions
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: VmoOptions) -> VmoOptions
pub const fn union(self, other: VmoOptions) -> VmoOptions
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: VmoOptions) -> VmoOptions
pub const fn difference(self, other: VmoOptions) -> VmoOptions
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: VmoOptions) -> VmoOptions
pub const fn symmetric_difference(self, other: VmoOptions) -> VmoOptions
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> VmoOptions
pub const fn complement(self) -> VmoOptions
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl VmoOptions
impl VmoOptions
Sourcepub const fn iter(&self) -> Iter<VmoOptions> ⓘ
pub const fn iter(&self) -> Iter<VmoOptions> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<VmoOptions> ⓘ
pub const fn iter_names(&self) -> IterNames<VmoOptions> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl VmoOptions
impl VmoOptions
pub fn from_bits_allow_unknown(bits: u32) -> VmoOptions
pub fn has_unknown_bits(&self) -> bool
pub fn get_unknown_bits(&self) -> u32