#[repr(C)]pub struct VmoReadVmoRequest {
pub handle: HandleId,
pub offset: u64,
pub size: u64,
}Fields
handle: HandleIdoffset: u64size: u64Trait Implementations
Sourceimpl Clone for VmoReadVmoRequest
impl Clone for VmoReadVmoRequest
Sourcefn clone(&self) -> VmoReadVmoRequest
fn clone(&self) -> VmoReadVmoRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for VmoReadVmoRequest
Sourceimpl Debug for VmoReadVmoRequest
impl Debug for VmoReadVmoRequest
Sourceimpl<D> Decode<VmoReadVmoRequest, D> for VmoReadVmoRequestwhere
D: ResourceDialect,
impl<D> Decode<VmoReadVmoRequest, D> for VmoReadVmoRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> VmoReadVmoRequest
fn new_empty() -> VmoReadVmoRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<VmoReadVmoRequest, D> for &VmoReadVmoRequestwhere
D: ResourceDialect,
impl<D> Encode<VmoReadVmoRequest, D> for &VmoReadVmoRequestwhere
D: ResourceDialect,
impl Eq for VmoReadVmoRequest
Sourceimpl Hash for VmoReadVmoRequest
impl Hash for VmoReadVmoRequest
Sourceimpl Ord for VmoReadVmoRequest
impl Ord for VmoReadVmoRequest
Sourcefn cmp(&self, other: &VmoReadVmoRequest) -> Ordering
fn cmp(&self, other: &VmoReadVmoRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for VmoReadVmoRequest
impl PartialEq for VmoReadVmoRequest
Sourceimpl PartialOrd for VmoReadVmoRequest
impl PartialOrd for VmoReadVmoRequest
impl Persistable for VmoReadVmoRequest
impl StructuralPartialEq for VmoReadVmoRequest
Sourceimpl TypeMarker for VmoReadVmoRequest
impl TypeMarker for VmoReadVmoRequest
Sourcetype Owned = VmoReadVmoRequest
type Owned = VmoReadVmoRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for VmoReadVmoRequest
impl ValueTypeMarker for VmoReadVmoRequest
Sourcetype Borrowed<'a> = &'a VmoReadVmoRequest
type Borrowed<'a> = &'a VmoReadVmoRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<VmoReadVmoRequest as TypeMarker>::Owned,
) -> <VmoReadVmoRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<VmoReadVmoRequest as TypeMarker>::Owned, ) -> <VmoReadVmoRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for VmoReadVmoRequest
impl RefUnwindSafe for VmoReadVmoRequest
impl Send for VmoReadVmoRequest
impl Sync for VmoReadVmoRequest
impl Unpin for VmoReadVmoRequest
impl UnsafeUnpin for VmoReadVmoRequest
impl UnwindSafe for VmoReadVmoRequest