pub struct VmoReadVmoResponse {
pub data: Vec<u8>,
}Fields
data: Vec<u8>Trait Implementations
Sourceimpl Clone for VmoReadVmoResponse
impl Clone for VmoReadVmoResponse
Sourcefn clone(&self) -> VmoReadVmoResponse
fn clone(&self) -> VmoReadVmoResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VmoReadVmoResponse
impl Debug for VmoReadVmoResponse
Sourceimpl<D> Decode<VmoReadVmoResponse, D> for VmoReadVmoResponsewhere
D: ResourceDialect,
impl<D> Decode<VmoReadVmoResponse, D> for VmoReadVmoResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> VmoReadVmoResponse
fn new_empty() -> VmoReadVmoResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<VmoReadVmoResponse, D> for &VmoReadVmoResponsewhere
D: ResourceDialect,
impl<D> Encode<VmoReadVmoResponse, D> for &VmoReadVmoResponsewhere
D: ResourceDialect,
impl Eq for VmoReadVmoResponse
Sourceimpl Hash for VmoReadVmoResponse
impl Hash for VmoReadVmoResponse
Sourceimpl Ord for VmoReadVmoResponse
impl Ord for VmoReadVmoResponse
Sourcefn cmp(&self, other: &VmoReadVmoResponse) -> Ordering
fn cmp(&self, other: &VmoReadVmoResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for VmoReadVmoResponse
impl PartialEq for VmoReadVmoResponse
Sourceimpl PartialOrd for VmoReadVmoResponse
impl PartialOrd for VmoReadVmoResponse
impl Persistable for VmoReadVmoResponse
impl StructuralPartialEq for VmoReadVmoResponse
Sourceimpl TypeMarker for VmoReadVmoResponse
impl TypeMarker for VmoReadVmoResponse
Sourcetype Owned = VmoReadVmoResponse
type Owned = VmoReadVmoResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for VmoReadVmoResponse
impl ValueTypeMarker for VmoReadVmoResponse
Sourcetype Borrowed<'a> = &'a VmoReadVmoResponse
type Borrowed<'a> = &'a VmoReadVmoResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<VmoReadVmoResponse as TypeMarker>::Owned,
) -> <VmoReadVmoResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<VmoReadVmoResponse as TypeMarker>::Owned, ) -> <VmoReadVmoResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for VmoReadVmoResponse
impl RefUnwindSafe for VmoReadVmoResponse
impl Send for VmoReadVmoResponse
impl Sync for VmoReadVmoResponse
impl Unpin for VmoReadVmoResponse
impl UnsafeUnpin for VmoReadVmoResponse
impl UnwindSafe for VmoReadVmoResponse