pub struct VmoWriteVmoRequest {
pub handle: HandleId,
pub offset: u64,
pub data: Vec<u8>,
}Fields
handle: HandleIdoffset: u64data: Vec<u8>Trait Implementations
Sourceimpl Clone for VmoWriteVmoRequest
impl Clone for VmoWriteVmoRequest
Sourcefn clone(&self) -> VmoWriteVmoRequest
fn clone(&self) -> VmoWriteVmoRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VmoWriteVmoRequest
impl Debug for VmoWriteVmoRequest
Sourceimpl<D> Decode<VmoWriteVmoRequest, D> for VmoWriteVmoRequestwhere
D: ResourceDialect,
impl<D> Decode<VmoWriteVmoRequest, D> for VmoWriteVmoRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> VmoWriteVmoRequest
fn new_empty() -> VmoWriteVmoRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<VmoWriteVmoRequest, D> for &VmoWriteVmoRequestwhere
D: ResourceDialect,
impl<D> Encode<VmoWriteVmoRequest, D> for &VmoWriteVmoRequestwhere
D: ResourceDialect,
impl Eq for VmoWriteVmoRequest
Sourceimpl Hash for VmoWriteVmoRequest
impl Hash for VmoWriteVmoRequest
Sourceimpl Ord for VmoWriteVmoRequest
impl Ord for VmoWriteVmoRequest
Sourcefn cmp(&self, other: &VmoWriteVmoRequest) -> Ordering
fn cmp(&self, other: &VmoWriteVmoRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for VmoWriteVmoRequest
impl PartialEq for VmoWriteVmoRequest
Sourceimpl PartialOrd for VmoWriteVmoRequest
impl PartialOrd for VmoWriteVmoRequest
impl Persistable for VmoWriteVmoRequest
impl StructuralPartialEq for VmoWriteVmoRequest
Sourceimpl TypeMarker for VmoWriteVmoRequest
impl TypeMarker for VmoWriteVmoRequest
Sourcetype Owned = VmoWriteVmoRequest
type Owned = VmoWriteVmoRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for VmoWriteVmoRequest
impl ValueTypeMarker for VmoWriteVmoRequest
Sourcetype Borrowed<'a> = &'a VmoWriteVmoRequest
type Borrowed<'a> = &'a VmoWriteVmoRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<VmoWriteVmoRequest as TypeMarker>::Owned,
) -> <VmoWriteVmoRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<VmoWriteVmoRequest as TypeMarker>::Owned, ) -> <VmoWriteVmoRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for VmoWriteVmoRequest
impl RefUnwindSafe for VmoWriteVmoRequest
impl Send for VmoWriteVmoRequest
impl Sync for VmoWriteVmoRequest
impl Unpin for VmoWriteVmoRequest
impl UnsafeUnpin for VmoWriteVmoRequest
impl UnwindSafe for VmoWriteVmoRequest